# yalecourses [![PyPI version](https://badge.fury.io/py/yalecourses.svg)](https://badge.fury.io/py/yalecourses)

> Python library for interfacing with the Yale Courses API.

[API documentation](https://developers.yale.edu/courses)

## Setup
First, install the module:

```sh
pip3 install yalecourses
```

Then, to use these functions, you must import the module:

```py
import yalecourses
```

Before using the library, you must instantiate its class, for example:

```py
courses = yalecourses.YaleCourses('your API key here')
```

You can obtain your API key as described [here](https://developers.yale.edu/how-info/how-do-i-get-access-apis).

## Retrieval Functions
- TODO

See `example.py` for several usage examples.

## Author
[Erik Boesen](https://github.com/ErikBoesen)

## License
[GPL](LICENSE)
